@@ -14,14 +14,19 @@ from qcodes.dataset.descriptions.dependencies import InterDependencies_
 from qcodes.dataset.descriptions.param_spec import ParamSpec, ParamSpecBase
 from qcodes.dataset.measurements import Measurement
 from qcodes.dataset.sqlite.database import connect, initialise_database
-from qcodes.instrument.parameter import (ArrayParameter, Parameter,
-                                         ParameterWithSetpoints)
-from qcodes.tests.instrument_mocks import (ArraySetPointParam,
-                                           DummyChannelInstrument,
-                                           DummyInstrument,
-                                           Multi2DSetPointParam,
-                                           Multi2DSetPointParam2Sizes,
-                                           setpoint_generator)
+from qcodes.instrument.parameter import (
+    ArrayParameter,
+    Parameter,
+    ParameterWithSetpoints,
+)
+from qcodes.tests.instrument_mocks import (
+    ArraySetPointParam,
+    DummyChannelInstrument,
+    DummyInstrument,
+    Multi2DSetPointParam,
+    Multi2DSetPointParam2Sizes,
+    setpoint_generator,
+)
 from qcodes.utils.validators import Arrays, ComplexNumbers, Numbers
 
 n_experiments = 0
@@ -582,18 +587,21 @@ def SpectrumAnalyzer():
 
     class Spectrum(ArrayParameter):
 
-        def __init__(self, name, instrument):
-            super().__init__(name=name,
-                             shape=(1,),  # this attribute should be removed
-                             label='Flower Power Spectrum',
-                             unit='V/sqrt(Hz)',
-                             setpoint_names=('Frequency',),
-                             setpoint_units=('Hz',))
+        def __init__(self, name, instrument, **kwargs):
+            super().__init__(
+                name=name,
+                shape=(1,),  # this attribute should be removed
+                label="Flower Power Spectrum",
+                unit="V/sqrt(Hz)",
+                setpoint_names=("Frequency",),
+                setpoint_units=("Hz",),
+                instrument=instrument,
+                **kwargs,
+            )
 
             self.npts = 100
             self.start = 0
             self.stop = 2e6
-            self._instrument = instrument
 
         def get_raw(self):
             # This is how it should be: the setpoints are generated at the
@@ -605,7 +613,7 @@ def SpectrumAnalyzer():
 
     class MultiDimSpectrum(ArrayParameter):
 
-        def __init__(self, name, instrument):
+        def __init__(self, name, instrument, **kwargs):
             self.start = 0
             self.stop = 2e6
             self.npts = (100, 50, 20)
@@ -617,15 +625,17 @@ def SpectrumAnalyzer():
                               self.npts[2])
             setpoints = setpoint_generator(sp1, sp2, sp3)
 
-            super().__init__(name=name,
-                             instrument=instrument,
-                             setpoints=setpoints,
-                             shape=(100, 50, 20),
-                             label='Flower Power Spectrum in 3D',
-                             unit='V/sqrt(Hz)',
-                             setpoint_names=('Frequency0', 'Frequency1',
-                                             'Frequency2'),
-                             setpoint_units=('Hz', 'Other Hz', "Third Hz"))
+            super().__init__(
+                name=name,
+                instrument=instrument,
+                setpoints=setpoints,
+                shape=(100, 50, 20),
+                label="Flower Power Spectrum in 3D",
+                unit="V/sqrt(Hz)",
+                setpoint_names=("Frequency0", "Frequency1", "Frequency2"),
+                setpoint_units=("Hz", "Other Hz", "Third Hz"),
+                **kwargs,
+            )
 
         def get_raw(self):
             return np.random.randn(*self.npts)
